# pyransame
PYthon RAndom SAmpling for MEshes

Utilites for choosing random samples of points within cells of [PyVista](https://github.com/pyvista/pyvista) meshes.
This package does _not_ choose random points that define the mesh itself, rather random points on the 2D surface or
in the 3D volume are sampled.

## Random sampling on a 2D surface

![Samples on a bunny](/doc/_static/surface_sampling.png)

## Random sampling in a 3D volume

![Samples inside a 3D volume](/doc/_static/volume_sampling.png)
